@@ -3,25 +3,29 @@ import inspect
 from datetime import datetime
 from typing import Union
 
+
 from . import _LOGGER
 
 from .devices import _WiserDeviceCollection
 from .helpers.automations import _WiserRoomAutomations
-from .helpers.extra_config import _WiserExtraConfig
 from .helpers.misc import is_value_in_list
 from .helpers.temp import _WiserTemperatureFunctions as tf
 from .rest_controller import _WiserRestController, WiserRestActionEnum
 from .schedule import _WiserSchedule, _WiserScheduleCollection
 
 from .const import (
+    DEFAULT_BOOST_DELTA,
     TEMP_MINIMUM,
     TEMP_OFF,
+    TEXT_BOOST,
     TEXT_MANUAL,
     TEXT_OFF,
     TEXT_ON,
     TEXT_UNKNOWN,
+    WISER_BOOST_DURATION,
     WISERROOM,
     WiserHeatingModeEnum,
+    WiserPresetOptionsEnum,
 )
 
 
@@ -41,16 +45,26 @@ class _WiserRoom(object):
         self._schedule = schedule
         self._devices = devices
         self._enable_automations = enable_automations
-        self._extra_config = self._wiser_rest_controller._extra_config.config(
-            "Rooms", str(self.id)
+        self._extra_config = (
+            self._wiser_rest_controller._extra_config.config("Rooms", str(self.id))
+            if self._wiser_rest_controller._extra_config
+            else None
         )
         self._mode = self._effective_heating_mode(
             self._data.get("Mode"), self.current_target_temperature
         )
+
         self._name = room.get("Name")
         self._window_detection_active = room.get("WindowDetectionActive", TEXT_UNKNOWN)
 
-        self._default_extra_config = {"passive_mode": False, "min": 14, "max": 18}
+        self._default_extra_config = {
+            "passive_mode": False,
+            "min": 14,
+            "max": 18,
+        }
+
+        self._boost_temperature_delta = DEFAULT_BOOST_DELTA
+        self.stored_manual_target_temperature_alt_source = "current"
 
         # Add device id to schedule
         if self._schedule:
@@ -58,10 +72,10 @@ class _WiserRoom(object):
 
     def _effective_heating_mode(self, mode: str, temp: float) -> str:
         if mode.casefold() == TEXT_MANUAL.casefold() and temp == TEMP_OFF:
-            return WiserHeatingModeEnum["off"].value
+            return WiserHeatingModeEnum.off.value
         elif mode.casefold() == TEXT_MANUAL.casefold():
-            return WiserHeatingModeEnum["manual"].value
-        return WiserHeatingModeEnum["auto"].value
+            return WiserHeatingModeEnum.manual.value
+        return WiserHeatingModeEnum.auto.value
 
     async def _send_command(
         self, cmd: dict, method: WiserRestActionEnum = WiserRestActionEnum.PATCH
@@ -88,41 +102,83 @@ class _WiserRoom(object):
             "Rooms", str(self.id), {key: value}
         )
 
+    @property
+    def is_passive_mode(self) -> bool:
+        return (
+            True
+            if self._enable_automations
+            and self.passive_mode_enabled
+            and self.mode != WiserHeatingModeEnum.off.value
+            and not self.is_boosted
+            else False
+        )
+
+    @property
+    def passive_mode_enabled(self) -> bool:
+        if self._extra_config and "passive_mode" in self._extra_config:
+            # Migrate from initial version of extra config
+            if (
+                self._extra_config["passive_mode"] == "Disabled"
+                or self._extra_config["passive_mode"] == False
+            ):
+                return False
+            else:
+                return True
+        return self._default_extra_config["passive_mode"]
+
     @property
     def passive_mode_lower_temp(self) -> float:
         if self._extra_config and "min" in self._extra_config:
-            return self._extra_config["min"]
-        return self._default_extra_config["min"]
+            return min(self._extra_config["min"], self.passive_mode_upper_temp)
+        return min(self._default_extra_config["min"], self.passive_mode_upper_temp)
 
     @property
     def passive_mode_upper_temp(self) -> float:
-        if self._extra_config and "max" in self._extra_config:
-            return self._extra_config["max"]
-        return self._default_extra_config["max"]
+        if (
+            self.is_passive_mode
+            and self.mode == WiserHeatingModeEnum.auto.value
+            and self.schedule
+        ):
+            return self.schedule.current_setting
+        else:
+            if self._extra_config and "max" in self._extra_config:
+                return self._extra_config["max"]
+            return self._default_extra_config["max"]
+
+    async def set_passive_mode(self, enable: bool):
+        await self._update_extra_config("passive_mode", enable)
+
+        # Set to min of temp range when initialised
+        if enable and self.mode != WiserHeatingModeEnum.off.value:
+            await self.set_target_temperature(self.passive_mode_lower_temp)
+
+        # Set target temp back to last manual temp if in manual mode
+        if (not enable) and self.mode == WiserHeatingModeEnum.manual.value:
+            await self.set_target_temperature(self.stored_manual_target_temperature)
 
     async def set_passive_mode_lower_temp(self, temp):
         await self._update_extra_config("min", temp)
-        await self.set_target_temperature(temp)
 
     async def set_passive_mode_upper_temp(self, temp):
         await self._update_extra_config("max", temp)
 
-    async def enable_passive_mode(self, enable: bool):
-        if self._enable_automations:
-            if enable:
-                self._mode = "Passive"
-                await self._update_extra_config("passive_mode", True)
-                await self._send_command({"Mode": WiserHeatingModeEnum.manual.value})
-                await self.set_target_temperature(self.passive_mode_lower_temp)
-            else:
-                await self._update_extra_config("passive_mode", False)
-                await self.set_mode(WiserHeatingModeEnum.auto)
-
     @property
-    def available_modes(self) -> str:
+    def available_modes(self) -> list:
         """Get available heating modes"""
         return [mode.value for mode in WiserHeatingModeEnum]
 
+    @property
+    def available_presets(self) -> list:
+        """Get available preset modes"""
+        # Remove advance schedule if no schedule exists or in passive mode
+        if self.is_passive_mode or not self.schedule:
+            return [
+                mode.value
+                for mode in WiserPresetOptionsEnum
+                if mode != WiserPresetOptionsEnum.advance_schedule
+            ]
+        return [mode.value for mode in WiserPresetOptionsEnum]
+
     @property
     def away_mode_suppressed(self) -> str:
         """Get if away mode is suppressed for room"""
@@ -143,6 +199,13 @@ class _WiserRoom(object):
         else:
             return 0
 
+    @property
+    def boost_temperature_delta(self) -> float:
+        return self._boost_temperature_delta
+
+    def set_boost_temperature_delta(self, temperature_delta: float):
+        self._boost_temperature_delta = temperature_delta
+
     @property
     def comfort_mode_score(self) -> int:
         """Get room heating comfort mode score"""
@@ -206,8 +269,8 @@ class _WiserRoom(object):
         return self._data.get("HeatingType", TEXT_UNKNOWN)
 
     @property
-    def hub_heating_mode(self) -> str:
-        self._effective_heating_mode(
+    def heating_mode(self) -> str:
+        return self._effective_heating_mode(
             self._data.get("Mode"), self.current_target_temperature
         )
 
@@ -265,12 +328,6 @@ class _WiserRoom(object):
     @property
     def mode(self) -> str:
         """Get or set current mode for the room (Off, Manual, Auto)"""
-        if (
-            self._enable_automations
-            and self._extra_config
-            and self._extra_config.get("passive_mode")
-        ):
-            self._mode = WiserHeatingModeEnum.passive.value
         return self._mode
 
     async def set_mode(self, mode: Union[WiserHeatingModeEnum, str]) -> bool:
@@ -290,7 +347,7 @@ class _WiserRoom(object):
                 ):
                     if self.current_target_temperature == TEMP_OFF:
                         await self.set_target_temperature(
-                            self.scheduled_target_temperature
+                            self.stored_manual_target_temperature
                         )
             elif mode == WiserHeatingModeEnum.auto.value:
                 await self._send_command({"Mode": WiserHeatingModeEnum.auto.value})
@@ -337,6 +394,37 @@ class _WiserRoom(object):
         """Get the percentage demand of the room"""
         return self._data.get("PercentageDemand", 0)
 
+    @property
+    def preset_mode(self) -> str:
+        """Get the current preset mode"""
+        if self.is_boosted:
+            return TEXT_BOOST
+        else:
+            return None
+
+    async def set_preset(self, preset: WiserPresetOptionsEnum | str):
+        """Set the preset mode"""
+        if type(preset) == WiserPresetOptionsEnum:
+            preset = preset.value
+
+        # Is it valid preset option?
+        if preset in self.available_presets:
+            if preset == WiserPresetOptionsEnum.cancel_overrides.value:
+                await self.cancel_overrides()
+            elif preset == WiserPresetOptionsEnum.advance_schedule.value:
+                await self.schedule_advance()
+            elif preset.lower().startswith(TEXT_BOOST.lower()):
+                # Lookup boost duration
+                duration = WISER_BOOST_DURATION[preset]
+                _LOGGER.info(
+                    f"Boosting by {self._boost_temperature_delta} for {duration}"
+                )
+                await self.boost(self._boost_temperature_delta, duration)
+        else:
+            raise ValueError(
+                f"{preset} is not a valid preset.  Valid presets are {self.available_presets}"
+            )
+
     @property
     def roomstat_id(self) -> int:
         """Get the id of the roomstat"""
@@ -362,6 +450,19 @@ class _WiserRoom(object):
         """Get list of smartvalve ids associated with room"""
         return sorted(self._data.get("SmartValveIds", []))
 
+    @property
+    def stored_manual_target_temperature(self) -> float:
+        if self._extra_config and "manual_temp" in self._extra_config:
+            return self._extra_config["manual_temp"]
+        elif self.stored_manual_target_temperature_alt_source == "current":
+            return self.current_temperature
+        elif (
+            self.stored_manual_target_temperature_alt_source == "scheduled"
+            and self.schedule
+        ):
+            return self.scheduled_target_temperature
+        return TEMP_MINIMUM
+
     @property
     def target_temperature_origin(self) -> str:
         """Get the origin of the target temperature setting for the room"""
@@ -438,6 +539,14 @@ class _WiserRoom(object):
         param temp: the temperature to set in C
         return: boolean
         """
+        # Set manual temp in stored config
+        if (
+            self.mode == WiserHeatingModeEnum.manual.value
+            and not self.is_passive_mode
+            and temp != TEMP_OFF
+        ):
+            await self._update_extra_config("manual_temp", temp)
+
         return await self._send_command(
             {
                 "RequestOverride": {
@@ -455,6 +564,10 @@ class _WiserRoom(object):
         param temp: the temperature to set in C
         return: boolean
         """
+        # Set manual temp in stored config
+        if self.mode == WiserHeatingModeEnum.manual.value and not self.is_passive_mode:
+            await self._update_extra_config("manual_temp", temp)
+
         return await self._send_command(
             {
                 "RequestOverride": {
@@ -500,7 +613,6 @@ class _WiserRoomCollection(_WiserRoomAutomations):
         room_data: dict,
         schedules: _WiserScheduleCollection,
         devices: _WiserDeviceCollection,
-        extra_config: _WiserExtraConfig,
         enable_automations: bool,
     ):
         super().__init__()
@@ -508,9 +620,8 @@ class _WiserRoomCollection(_WiserRoomAutomations):
         self._room_data = room_data
         self._schedules = schedules
         self._devices = devices
-        self._extra_config = extra_config
         self._enable_automations = enable_automations
-        self._rooms = []
+        self._rooms: list(_WiserRoom) = []
         self._build()
 
     def _build(self):
